### First Step 
- Assign Labels : Type of PR (Bug/Feature), Scope (tiny, small,... huge) 
- Request a reviewer or assign tasks 
- Then start to fill the following form:

# Addressed issues
*  the list
*  of issues
*  e.g. #200 

# Description
A more detailed  
description of your  
changes goes here  

## Subsection
more details

### Subsubsection 2
more and more details

## New Feature Showcase 
If applicable, a short / one-liner example to highlight the new feature


# Check list
### Test documentation (delete if not applicable)
* [ ]  Build Debug
* [ ]  Build Release Mode
* [ ]  Executed Tests
* [ ]  Build Tests
* [ ]  Executed Examples
* [ ]  Added new unit test for new feature

### Documentation of changes and theory
* [ ]  I have updated the relevant documentations, as far as necessary.

### Style guide compliance
* [ ]  Edited `C++` files formatted with clang-format (`10.x.x`+)

